@@ -68,6 +68,8 @@ totem_gallery_new (Totem *totem, TotemPlugin *plugin)
 	TotemGallery *gallery;
 	GtkWidget *container;
 	GtkBuilder *builder;
+	gchar *movie_title, *uri, *suggested_name;
+	GFile *file;
 
 	/* Create the gallery and its interface */
 	gallery = g_object_new (TOTEM_TYPE_GALLERY, NULL);
@@ -102,8 +104,26 @@ totem_gallery_new (Totem *totem, TotemPlugin *plugin)
 	container = GTK_WIDGET (gtk_builder_get_object (builder,
 				"gallery_dialog_content"));
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (gallery), container);
-	/* Translators: the argument is a screenshot number, used to prevent overwriting files. Just translate "Screenshot", and not the ".jpg". */
-	totem_screenshot_plugin_setup_file_chooser (GTK_FILE_CHOOSER (gallery), N_("Screenshot%d.jpg"));
+
+	movie_title = totem_get_short_title (totem);
+
+	/* Translators: The first argument is the movie title. The second
+	 * argument is a number which is used to prevent overwriting files.
+	 * Just translate "Gallery", and not the ".jpg". Example:
+	 * "Galerie-%s-%d.jpg". */
+	uri = totem_screenshot_plugin_setup_file_chooser (N_("Gallery-%s-%d.jpg"), movie_title);
+	g_free (movie_title);
+
+	file = g_file_new_for_uri (uri);
+	/* We can use g_file_get_basename here and be sure that it's UTF-8
+	 * because we provided the name. */
+	suggested_name = g_file_get_basename (file);
+	g_object_unref (file);
+
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (gallery), uri);
+	g_free (uri);
+	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (gallery), suggested_name);
+	g_free (suggested_name);
 
 	gtk_widget_show_all (GTK_WIDGET (gallery));
 
@@ -148,10 +168,10 @@ dialog_response_callback (GtkDialog *dialog, gint response_id, TotemGallery *sel
 	totem_screenshot_plugin_update_file_chooser (filename);
 
 	/* Build the command and arguments to pass it */
-	argv[0] = "totem-video-thumbnailer";
-	argv[1] = "-j"; /* JPEG mode */
-	argv[2] = "-l"; /* don't limit resources */
-	argv[3] = "-p"; /* print progress */
+	argv[0] = (gchar*) "totem-video-thumbnailer"; /* a little hacky, but only the allocated stuff is freed below */
+	argv[1] = (gchar*) "-j"; /* JPEG mode */
+	argv[2] = (gchar*) "-l"; /* don't limit resources */
+	argv[3] = (gchar*) "-p"; /* print progress */
 	argv[4] = g_strdup_printf ("--gallery=%u", screenshot_count); /* number of screenshots to output */
 	argv[5] = g_strdup_printf ("--size=%u", gtk_spin_button_get_value_as_int (self->priv->screenshot_width)); /* screenshot width */
 	argv[6] = video_mrl; /* video to thumbnail */
