@@ -31,6 +31,7 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
+#include <unique/uniqueapp.h>
 
 #include "totem-playlist.h"
 #include "bacon-video-widget.h"
@@ -157,7 +158,7 @@ struct _TotemObject {
 	gint64 seek_to;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	GApplication *app;
+	UniqueApp *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
 	gboolean remember_position;
