@@ -34,6 +34,15 @@
 #include "totem-uri.h"
 #include "totem-private.h"
 
+/* 5 minute threshold. We don't want to save the position within a 3
+ * minute song for example. */
+#define SAVE_POSITION_THRESHOLD 5 * 60 * 1000
+/* Don't save the position of a stream if we're within 5% of the beginning or end so that,
+ * for example, we don't save if the user exits when they reach the credits of a film */
+#define SAVE_POSITION_END_THRESHOLD 0.05
+/* The GIO file attribute used to store the position in a stream */
+#define SAVE_POSITION_FILE_ATTRIBUTE "metadata::totem::position"
+
 static GtkFileFilter *filter_all = NULL;
 static GtkFileFilter *filter_subs = NULL;
 static GtkFileFilter *filter_supported = NULL;
@@ -129,12 +138,44 @@ totem_get_mount_for_uri (const char *path)
 	return mount;
 }
 
-static char *
-totem_get_mountpoint_for_dvd (const char *uri)
+static GMount *
+totem_get_mount_for_dvd (const char *uri)
 {
-	if (g_str_has_prefix (uri, "dvd://") == FALSE)
-		return NULL;
-	return g_strdup (uri + strlen ("dvd://"));
+	GMount *mount;
+	char *path;
+
+	mount = NULL;
+	path = g_strdup (uri + strlen ("dvd://"));
+
+	/* If it's a device, we need to find the volume that corresponds to it,
+	 * and then the mount for the volume */
+	if (g_str_has_prefix (path, "/dev/")) {
+		GVolumeMonitor *volume_monitor;
+		GList *volumes, *l;
+
+		volume_monitor = g_volume_monitor_get ();
+		volumes = g_volume_monitor_get_volumes (volume_monitor);
+		g_object_unref (volume_monitor);
+
+		for (l = volumes; l != NULL; l = l->next) {
+			char *id;
+
+			id = g_volume_get_identifier (l->data, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+			if (g_strcmp0 (id, path) == 0) {
+				g_free (id);
+				mount = g_volume_get_mount (l->data);
+				break;
+			}
+			g_free (id);
+		}
+		g_list_foreach (volumes, (GFunc) g_object_unref, NULL);
+		g_list_free (volumes);
+	} else {
+		mount = totem_get_mount_for_uri (path);
+		g_free (path);
+	}
+	/* We have a path to the file itself */
+	return mount;
 }
 
 static char *
@@ -155,7 +196,7 @@ totem_get_mount_for_media (const char *uri)
 	mount_path = NULL;
 
 	if (g_str_has_prefix (uri, "dvd://") != FALSE)
-		mount_path = totem_get_mountpoint_for_dvd (uri);
+		return totem_get_mount_for_dvd (uri);
 	else if (g_str_has_prefix (uri, "vcd:") != FALSE)
 		mount_path = totem_get_mountpoint_for_vcd (uri);
 	else if (g_str_has_prefix (uri, "file:") != FALSE)
@@ -403,7 +444,9 @@ totem_uri_get_subtitle_uri (const char *uri)
 	GFile *file;
 	char *subtitle;
 
-	if (g_str_has_prefix (uri, "http") != FALSE)
+	if (g_str_has_prefix (uri, "http") != FALSE ||
+	    g_str_has_prefix (uri, "rtsp") != FALSE ||
+	    g_str_has_prefix (uri, "rtmp") != FALSE)
 		return NULL;
 
 	/* Has the user specified a subtitle file manually? */
@@ -534,27 +577,14 @@ totem_add_default_dirs (GtkFileChooser *dialog)
 	}
 }
 
-void
-totem_add_pictures_dir (GtkWidget *chooser)
-{
-	const char *dir;
-
-	g_return_if_fail (GTK_IS_FILE_CHOOSER (chooser) != FALSE);
-
-	dir = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
-	if (dir == NULL)
-		return;
-	gtk_file_chooser_add_shortcut_folder (GTK_FILE_CHOOSER (chooser), dir, NULL);
-}
-
 char *
-totem_add_subtitle (GtkWindow *parent, const char *path)
+totem_add_subtitle (GtkWindow *parent, const char *uri)
 {
 	GtkWidget *fs;
 	GConfClient *conf;
 	char *new_path;
 	char *subtitle = NULL;
-	gboolean set_folder;
+	gboolean folder_set;
 
 	fs = gtk_file_chooser_dialog_new (_("Select Text Subtitles"), 
 					  parent,
@@ -569,8 +599,9 @@ totem_add_subtitle (GtkWindow *parent, const char *path)
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (fs), filter_subs);
 
 	conf = gconf_client_get_default ();
-	set_folder = TRUE;
+	folder_set = FALSE;
 
+	/* Add the subtitles cache dir as a shortcut */
 	new_path = g_build_filename (g_get_user_cache_dir (),
 				     "totem",
 				     "subtitles",
@@ -578,22 +609,22 @@ totem_add_subtitle (GtkWindow *parent, const char *path)
 	gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER (fs), new_path, NULL);
 	g_free (new_path);
 
+	/* Add the last open path as a shortcut */
 	new_path = gconf_client_get_string (conf, "/apps/totem/open_path", NULL);
 	if (new_path != NULL && *new_path != '\0') {
-		set_folder = gtk_file_chooser_set_current_folder_uri
-			(GTK_FILE_CHOOSER (fs), new_path);
+		gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER (fs), new_path, NULL);
 	}
 	g_free (new_path);
 
-	if (path != NULL) {
-		if (set_folder == FALSE) {
-			set_folder = gtk_file_chooser_set_current_folder_uri
-				(GTK_FILE_CHOOSER (fs), path);
-		}
-		gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER (fs), path, NULL);
+	/* Try to set the passed path as the current folder */
+	if (uri != NULL) {
+		folder_set = gtk_file_chooser_set_current_folder_uri
+			(GTK_FILE_CHOOSER (fs), uri);
+		gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER (fs), uri, NULL);
 	}
 	
-	if (set_folder == FALSE) {
+	/* And set it as home if it fails */
+	if (folder_set == FALSE) {
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fs),
 						     g_get_home_dir ());
 	}
@@ -682,3 +713,91 @@ totem_add_files (GtkWindow *parent, const char *path)
 	return filenames;
 }
 
+void
+totem_save_position (Totem *totem)
+{
+	gint64 stream_length, position;
+	char *pos_str;
+	GFile *file;
+	GError *error = NULL;
+
+	if (totem->remember_position == FALSE)
+		return;
+	if (totem->mrl == NULL)
+		return;
+
+	stream_length = bacon_video_widget_get_stream_length (totem->bvw);
+	position = bacon_video_widget_get_current_time (totem->bvw);
+
+	file = g_file_new_for_uri (totem->mrl);
+
+	/* Don't save if it's:
+	 *  - a live stream
+	 *  - too short to make saving useful
+	 *  - too close to the beginning or end to make saving useful
+	 */
+	if (stream_length < SAVE_POSITION_THRESHOLD ||
+	    (stream_length - position) < stream_length * SAVE_POSITION_END_THRESHOLD ||
+	    position < stream_length * SAVE_POSITION_END_THRESHOLD) {
+		g_debug ("not saving position because the video/track is too short");
+
+		/* Remove the attribute if it is currently set on the file; this ensures that if we start watching a stream and save the position
+		 * half-way through, then later continue watching it to the end, the mid-way saved position will be removed when we finish the
+		 * stream. Only do this for non-live streams. */
+		if (stream_length > 0) {
+			g_file_set_attribute_string (file, SAVE_POSITION_FILE_ATTRIBUTE, "", G_FILE_QUERY_INFO_NONE, NULL, &error);
+			if (error != NULL) {
+				g_warning ("g_file_set_attribute_string failed: %s", error->message);
+				g_error_free (error);
+			}
+		}
+
+		g_object_unref (file);
+		return;
+	}
+
+	g_debug ("saving position: %"G_GINT64_FORMAT, position);
+
+	/* Save the position in the stream as a file attribute */
+	pos_str = g_strdup_printf ("%"G_GINT64_FORMAT, position);
+	g_file_set_attribute_string (file, SAVE_POSITION_FILE_ATTRIBUTE, pos_str, G_FILE_QUERY_INFO_NONE, NULL, &error);
+	g_free (pos_str);
+
+	if (error != NULL) {
+		g_warning ("g_file_set_attribute_string failed: %s", error->message);
+		g_error_free (error);
+	}
+	g_object_unref (file);
+}
+
+void
+totem_try_restore_position (Totem *totem, const char *mrl)
+{
+	GFile *file;
+	GFileInfo *file_info;
+	const char *seek_str;
+
+	if (totem->remember_position == FALSE)
+		return;
+
+	if (mrl == NULL)
+		return;
+
+	file = g_file_new_for_uri (mrl);
+	g_debug ("trying to restore position of: %s", mrl);
+
+	/* Get the file attribute containing the position */
+	file_info = g_file_query_info (file, SAVE_POSITION_FILE_ATTRIBUTE, G_FILE_QUERY_INFO_NONE, NULL, NULL);
+	g_object_unref (file);
+
+	if (file_info == NULL)
+		return;
+
+	seek_str = g_file_info_get_attribute_string (file_info, SAVE_POSITION_FILE_ATTRIBUTE);
+	g_debug ("seek time: %s", seek_str);
+
+	if (seek_str != NULL)
+		totem->seek_to = g_ascii_strtoull (seek_str, NULL, 0);
+
+	g_object_unref (file_info);
+}
